﻿using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Options;
using System.Text.Encodings.Web;
using System.Text.Json;
using System.Text.Json.Serialization;
using System.Text.Unicode;


//====================================================
// Описание работы классов и методов исходника на:
// https://www.interestprograms.ru
// Исходные коды программ и игр
// Автор исходных кодов Клочков Павел
//====================================================

namespace ASPNETMVCAjaxJavaSscript.Controllers
{
    public class AjaxController : Controller
    {
        private readonly JsonSerializerOptions _options = new();

        public AjaxController()
        {
            _options.Encoder = JavaScriptEncoder.Create(UnicodeRanges.All);
        }


        [Route("/application-json")]
        [HttpPost]
        [ValidateAntiForgeryToken]
        public IActionResult JsonText([FromBody] JsonObj jsonObj)
        {
            return Json(jsonObj, _options);
        }

        // Другие варианты получения JSON данных
        //public async Task<IActionResult> JsonTextAsync()
        //{
        //    var httpRequest = HttpContext.Request;
        //    JsonObj? jsonObj = await JsonSerializer.DeserializeAsync<JsonObj>(httpRequest.Body, _options);

        //    return Content(JsonSerializer.Serialize(jsonObj));
        //}


        //public async Task<IActionResult> JsonTextAsync_2()
        //{
        //    var httpRequest = HttpContext.Request;
        //    if (httpRequest.ContentLength == null) return BadRequest();

        //    byte[] buffer = new byte[(int)httpRequest.ContentLength];
        //    await httpRequest.Body.ReadAsync(buffer, 0, buffer.Length);
        //    JsonObj? jsonObj = JsonSerializer.Deserialize<JsonObj>(buffer, _options);

        //    return Content(JsonSerializer.Serialize(jsonObj));
        //}

        /// <summary>
        /// Структура аналогичная по типам и названиям свойств
        /// объекту JSON полученного от клиента
        /// </summary>
        public class JsonObj
        {
            public string? api { get; set; }
            public string? inputText { get; set; }
            public string? inputNumber { get; set; }
            public bool inputCheck { get; set; }
        }
    }
}
